<?php
# file companyquery.inc

# we are doing a query with the company data


$fields		= 'company_name, address1, address2, city, state_id, zip';
$fields		.= ', contact_name, contact_title, contact_email, url';
$fields		.= ', phone_area, phone_exchange, phone_digits, phone_extension';
$fields		.= ', fax_area, fax_exchange, fax_digits, fax_extension';
$values		= "'$company_name', '$address1', '$address2', '$city', '$state_id', '$zip'";
$values		.= ", '$contact_name', '$contact_title', '$contact_email', '$url'";
$values		.= ", '$phone_area', '$phone_exchange', '$phone_digits', '$phone_extension'";
$values		.= ", '$fax_area', '$fax_exchange', '$fax_digits', '$fax_extension'";

$table		= 'company';
@mysql_query ("INSERT INTO $table ($fields) VALUES ($values)", $link);

echo "<big><b>Thanks. Company \"$company_name\" was added to the database.</b></big><br>\n";

include('dberrors_insert.inc');

?>

