<?php
# file editcompanyform.inc

# we are presenting a company edit form to the user

?>


<form action="<?= $_SERVER['PHP_SELF'] ?>" method="POST" enctype="text">
<p><big><b>Please fill in the company information:</b></big></p>
<table>
  <tr>
    <td><b>Company Name:</b> </td>
    <td><input type="text" name="company_name" size=90 value="<?= $company_name ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>Address 1:</b>  </td>
    <td><input type="text" name="address1" size=40 value="<?= $address1 ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
    <tr>
    <td><b>Address 2:</b>  </td>
    <td><input type="text" name="address2" size=40 value="<?= $address2 ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>City:</b>  </td>
    <td><input type="text" name="city" size=30 value="<?= $city ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>State:</b>  </td>
    <td><input type="text" name="state_id" size=2 value="<?= $state_id ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>Zip Code:</b>  </td>
    <td><input type="text" name="zip" size=7 value="<?= $zip ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>Contact's Name:</b>  </td>
    <td><input type="text" name="contact_name" size=30 value="<?= $contact_name ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
    <tr>
    <td><b>Contact's Title:</b>  </td>
    <td><input type="text" name="contact_title" size=30 value="<?= $contact_title ?>">  </td>
    <td>  </td>
    <td>  </td>
  <tr>
    <td><b>Contact's Email Address:</b>  </td>
    <td><input type="text" name="contact_email" size=30 value="<?= $contact_email ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
    <tr>
    <td><b>Website:</b>  </td>
    <td><input type="text" name="url" size=30 value="<?= $url ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>Phone Number:</b>  </td>
    <td>(&nbsp;<input type="text" name="phone_area" size=3 value="<?= $phone_area ?>">&nbsp;)&nbsp;
    <input type="text" name="phone_exchange" size=3 value="<?= $phone_exchange ?>">&nbsp;&nbsp;-&nbsp;
	<input type="text" name="phone_digits" size=4 value="<?= $phone_digits ?>">&nbsp;&nbsp;Ext.&nbsp;
    <input type="text" name="phone_extension" size=4 value="<?= $phone_extension ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
  <tr>
    <td><b>Fax:</b>  </td>
    <td>(&nbsp;<input type="text" name="fax_area" size=3 value="<?= $fax_area ?>">&nbsp;)&nbsp;
    <input type="text" name="fax_exchange" size=3 value="<?= $fax_exchange ?>">&nbsp;&nbsp;-&nbsp;
	<input type="text" name="fax_digits" size=4 value="<?= $fax_digits ?>">&nbsp;&nbsp;Ext.&nbsp;
    <input type="text" name="fax_extension" size=4 value="<?= $fax_extension ?>">  </td>
    <td>  </td>
    <td>  </td>
  </tr>
</table>
</p>

<?php
#Please enter your password in order to write to the database:
#<input type="password" name="password" size=16">
?>

<p><input type=checkbox name="verified" value="true"> All data has been verified.
<p><input type=submit value="Submit"></p>
</form>


