<?php
# footer for invoice app
?>

<hr>
<table width="100%" cols=2>
  <tr>
    <td align="left" valign="top"><font color="#009900">Please make checks payable to:
      <br><b>Joey Kelly
      <br>324 Codifer Blvd. Suite 9
      <br>Metairie, LA 70005</b>
      <br><i>Thank you very much for your patronage.</font></i>
    <td>
    <td align="right" valign="top">
    <?php
    # only print clean page if we are not giving client an invoice
    if (!($type_name == "Invoice"))
      {
        echo "<b><font color=red><big><big>$type_name only.<br>This is not a bill.</b></big></big></font>";
      };
    ?>
    </td>
  </tr>
</table>
</body>
</html>
